@@ -213,6 +213,15 @@
 #'  }
 #'  However, note that this may be less reliable since the email message could be directed to a spam folder.
 #'
+#' @param store_warning_seeds logical; in addition to storing the \code{.Random.seed} states whenever error messages
+#'   are raised, also store the \code{.Random.seed} states when warnings are raised? This is disabled by default
+#'   since warnings are generally less problematic than errors, and because many more warnings messages may be raised
+#'   throughout the simulation (potentially causing RAM related issues when constructing the final simulation object as
+#'   any given simulation replicate could generate numerous warnings, and storing the seeds states could add up quickly).
+#'
+#'   Set this to \code{TRUE} when replicating warning messages is important, however be aware that too many warnings
+#'   messages raised during the simulation implementation could cause RAM related issues.
+#'
 #' @param warnings_as_errors logical; treat warning messages as error messages during the simulation? Default is FALSE,
 #'   therefore warnings are only collected and not used to restart the data generation step, and the seeds associated with
 #'   the warning message conditions are not stored within the final simulation object
@@ -366,9 +375,15 @@
 #'
 #' @param store_results logical; store the complete tables of simulation results
 #'   in the returned object? This is \code{FALSE} by default to help avoid RAM
-#'   issues (see \code{save_results} as a more suitable alternative). To extract these results
+#'   issues (see \code{save_results} as a more suitable alternative). However, if the \code{Design}
+#'   object is omitted from the call to \code{runSimulation()}, or the number of rows in \code{Design}
+#'   is exactly 1, then this argument is automatically set to \code{TRUE} as RAM storage will no
+#'   longer be an issue.
+#'
+#'   To extract these results
 #'   pass the returned object to \code{SimExtract(..., what = 'results')}, which will return a named list
-#'   of all the simulation results for each condition
+#'   of all the simulation results for each condition if \code{nrow(Design) > 1}; otherwise, if
+#'   \code{nrow(Design) == 1} or \code{Design} was missing the \code{results} object will be stored as-is
 #'
 #' @param stop_on_fatal logical; should the simulation be terminated immediately when
 #'   the maximum number of consecutive errors (\code{max_errors}) is reached? If \code{FALSE},
@@ -689,7 +704,8 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                           save_results = FALSE, parallel = FALSE, ncores = parallel::detectCores(), cl = NULL,
                           notification = NULL, boot_method='none', boot_draws = 1000L, CI = .95,
                           seed = rint(nrow(design), min=1L, max = 2147483647L), save_seeds = FALSE,
-                          save = TRUE, store_results = FALSE, warnings_as_errors = FALSE, max_errors = 50L,
+                          save = TRUE, store_results = FALSE, store_warning_seeds = FALSE,
+                          warnings_as_errors = FALSE, max_errors = 50L,
                           allow_na = FALSE, allow_nan = FALSE, stop_on_fatal = FALSE, MPI = FALSE,
                           save_details = list(), progress = TRUE, verbose = TRUE)
 {
@@ -705,7 +721,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                 message('NA value for summarise input supplied; automatically setting save_results to TRUE\n')
             save <- save_results <- TRUE
         }
-    }
+    } else save <- FALSE
     if(!all(names(save_results) %in%
             c('compname', 'save_results_dirname')))
         stop('save_details contains elements that are not supported', call.=FALSE)
@@ -746,7 +762,10 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
         design <- data.frame(dummy_run=NA)
         dummy_run <- TRUE
     }
-    if(nrow(design) == 1L) verbose <- FALSE
+    if(nrow(design) == 1L){
+        verbose <- FALSE
+        store_results <- TRUE
+    }
     stopifnot(!missing(replications))
     replications <- as.integer(replications)
     if(!is.null(seed))
@@ -930,6 +949,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                                          boot_draws=boot_draws, boot_method=boot_method, CI=CI,
                                          save=save, allow_na=allow_na, allow_nan=allow_nan,
                                          save_results=save_results,
+                                         store_warning_seeds=store_warning_seeds,
                                          save_results_out_rootdir=out_rootdir,
                                          save_results_dirname=save_results_dirname,
                                          save_seeds=save_seeds, summarise_asis=summarise_asis,
@@ -956,6 +976,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                             boot_method=boot_method, boot_draws=boot_draws, CI=CI,
                             save=save, allow_na=allow_na, allow_nan=allow_nan,
                             save_results=save_results,
+                            store_warning_seeds=store_warning_seeds,
                             save_results_out_rootdir = out_rootdir,
                             save_results_dirname=save_results_dirname,
                             save_seeds=save_seeds, summarise_asis=summarise_asis,
@@ -972,6 +993,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
             Result_list[[i]] <- data.frame(design[i, ], as.list(tmp),
                                            check.names=FALSE)
             attr(Result_list[[i]], 'error_seeds') <- attr(tmp, 'error_seeds')
+            attr(Result_list[[i]], 'warning_seeds') <- attr(tmp, 'warning_seeds')
             Result_list[[i]]$SIM_TIME <- proc.time()[3L] - time0
             Result_list[[i]]$COMPLETED <- date()
             if(save || save_results)
@@ -999,7 +1021,8 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
         if(is.list(Result_list[[1L]][[1L]]))
             for(i in seq_len(length(Result_list)))
                 attr(Result_list[[i]][[1L]], 'try_errors') <-
-            attr(Result_list[[i]][[1L]], 'try_error_seeds') <- NULL
+                attr(Result_list[[i]][[1L]], 'try_error_seeds') <-
+                attr(Result_list[[i]][[1L]], 'warning_seeds') <- NULL
         if(nrow(design) == 1L) Result_list <- Result_list[[1L]]
         return(Result_list)
     }
@@ -1014,6 +1037,13 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                                 rownames(ret))
         t(ret)
     })))
+    warning_seeds <- data.frame(do.call(cbind, lapply(1L:length(Result_list), function(x){
+        ret <- attr(Result_list[[x]], "warning_seeds")
+        if(length(ret) == 0L || nrow(ret) == 0L) return(NULL)
+        rownames(ret) <- paste0("Design_row_", x, '.', 1L:nrow(ret), ": ",
+                                rownames(ret))
+        t(ret)
+    })))
     Final <- plyr::rbind.fill(Result_list)
     if(!stop_on_fatal && any(colnames(Final) == 'FATAL_TERMINATION')){
         warning('One or more design rows were fatally terminated. Please inspect/debug row(s): ',
@@ -1081,6 +1111,7 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                                       number_of_conditions = nrow(design),
                                       date_completed = date(), total_elapsed_time = sum(Final$SIM_TIME),
                                       error_seeds=dplyr::as_tibble(error_seeds),
+                                      warning_seeds=dplyr::as_tibble(warning_seeds),
                                       stored_results = if(store_results) stored_Results_list else NULL)
     if(dummy_run) Final$dummy_run <- NULL
     class(Final) <- c('SimDesign', class(Final))
