@@ -39,6 +39,11 @@
 #'
 #' @seealso \code{\link{RMSE}}
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -162,6 +167,11 @@ bias <- function(estimate, parameter = NULL, type = 'bias', abs = FALSE,
 #'
 #' @seealso \code{\link{bias}}
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -251,6 +261,10 @@ RMSE <- function(estimate, parameter = NULL, type = 'RMSE', MSE = FALSE,
     ret
 }
 
+#' @rdname RMSE
+#' @export
+RMSD <- RMSE
+
 #' Compute the integrated root mean-square error
 #'
 #' Computes the average/cumulative deviation given two continuous functions and an optional
@@ -291,6 +305,11 @@ RMSE <- function(estimate, parameter = NULL, type = 'RMSE', MSE = FALSE,
 #' @seealso \code{\link{RMSE}}
 #'
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -370,6 +389,11 @@ IRMSE <- function(estimate, parameter, fn, density = function(theta, ...) 1,
 #'
 #' @export MAE
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -462,6 +486,11 @@ MAE <- function(estimate, parameter = NULL, type = 'MAE',
 #'
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -515,6 +544,11 @@ RE <- function(x, MSE = FALSE, percent = FALSE, unname = FALSE){
 #'
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -585,6 +619,11 @@ RAB <- function(x, percent = FALSE, unname = FALSE){
 #'
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -656,6 +695,11 @@ MSRSE <- function(SE, SD, percent = FALSE, unname = FALSE){
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #'
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -716,6 +760,11 @@ RD <- function(est, pop, as.vector = TRUE, unname = FALSE){
 #'
 #' @export EDR
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -785,6 +834,11 @@ EDR <- function(p, alpha = .05, unname = FALSE){
 #'
 #' @seealso \code{\link{EDR}}
 #' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
 #' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
 #' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
 #' \doi{10.1080/10691898.2016.1246953}
@@ -880,3 +934,68 @@ ECR <- function(CIs, parameter, tails = FALSE, CI_width = FALSE,
     ret
 }
 
+#' Compute congruence coefficient
+#'
+#' Computes the congruence coefficient, also known as an "unadjusted" correlation
+#' or Tucker's congruence coefficient.
+#'
+#' @param x a vector or \code{data.frame}/\code{matrix} containing the
+#'   variables to use. If a vector then the input \code{y} is required,
+#'   otherwise the cogruence coefficient is computed for all bivariate
+#'   combinations
+#'
+#' @param y (optional) the second vector input to use if
+#'   \code{x} is a vector
+#'
+#' @param unname logical; apply \code{\link{unname}} to the results to remove any variable
+#'   names?
+#'
+#' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
+#'
+#' @seealso \code{\link{cor}}
+#'
+#' @export
+#' @references
+#'
+#' Chalmers, R. P., & Adkins, M. C.  (2020). Writing Effective and Reliable Monte Carlo Simulations
+#' with the SimDesign Package. \code{The Quantitative Methods for Psychology, 16}(4), 248-280.
+#' \doi{10.20982/tqmp.16.4.p248}
+#'
+#' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
+#' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
+#' \doi{10.1080/10691898.2016.1246953}
+#'
+#' @examples
+#'
+#' vec1 <- runif(1000)
+#' vec2 <- runif(1000)
+#'
+#' CC(vec1, vec2)
+#' # compare to cor()
+#' cor(vec1, vec2)
+#'
+#' # column input
+#' df <- data.frame(vec1, vec2, vec3 = runif(1000))
+#' CC(df)
+#' cor(df)
+#'
+CC <- function(x, y = NULL, unname = FALSE){
+    cc <- function(x,y)
+        sum(x * y) / (sqrt(sum(x^2) * sum(y^2)))
+    if(!is.null(y)) x <- data.frame(x, y)
+    if(is.data.frame(x)) x <- as.matrix(x)
+    if(ncol(x) == 2){
+        ret <- cc(x[,1], x[,2])
+    } else {
+        J <- ncol(x)
+        ret <- matrix(0, ncol=J, nrow=J)
+        colnames(ret) <- rownames(ret) <- colnames(x)
+        for(i in 1L:(J-1L))
+            for(j in (i+1):J)
+                ret[i,j] <- cc(x[,i], x[,j])
+        ret <- ret + t(ret)
+        diag(ret) <- 1
+    }
+    if(unname) ret <- unname(ret)
+    ret
+}
